# Telliot Feed Examples

## Overview

This package provides several examples demonstrating how to 
incorporate the `telliot-core` package into working TellorX 
reporter feeds.


## Scope

The TellorX network is open to everyone, and these examples are just
one way to access it.  You can use all of this repo, parts of it, or not
use it at all.  You can also make contributions to improve it.


!!! warning
    Use Telliot and all it's components at your own risk.  **It may have bugs!  Bugs may cost you real money!**
    If you find any, please [submit an issue](https://github.com/tellor-io/telliot-core/issues),
    or better yet [create a pull request](https://github.com/tellor-io/telliot-core/pulls)
    with a suggested fix.

